==> geopsypack-src-3.3.4.tar.gz: geopsypack-src-3.3.4/SciFigs/src/PlotLine.h <==
/***************************************************************************
**
**  This file is part of SciFigs.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2004-10-07
**  Copyright: 2004-2019
**    Marc Wathelet
**    Marc Wathelet (ULg, Liège, Belgium)
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef PLOTLINE_H
#define PLOTLINE_H

#include "SciFigsDLLExport.h"
#include "AbstractLine.h"

namespace SciFigs {

class SCIFIGS_EXPORT PlotLine : public AbstractLine
{
public:
  virtual AbstractLine * clone() const;
  virtual void operator=(const PlotLine& o);

  virtual int count() const {return _curve.count();}
  virtual void clear() {_curve.clear();}
  virtual void append() {_curve.append(Point());}
  virtual void insert(int index) {_curve.insert(index, Point());}
  virtual void removeLast() {_curve.remove(_curve.count()-1);}
  virtual bool isSorted() const {return _curve.isSorted();}
  virtual void checkSort() {_curve.checkSort();}
  virtual void indexRange(double xMin, double xMax, int& indexMin, int& indexMax) const {
    return _curve.indexRange(xMin, xMax, indexMin, indexMax);
  }
  virtual Point point(int index, const CurvePointOptions *) const {return _curve.at(index);}
  virtual void setX(int index, double v) {_curve[index].setX(v);}
  virtual void setY(int index, double v, const CurvePointOptions *) {_curve[index].setY(v);}
  virtual void setZ(int index, double v, const CurvePointOptions *) {_curve[index].setZ(v);}

  const Curve<Point>& curve() const {return _curve;}
  Curve<Point>& curve() {return _curve;}
protected:
  Curve<Point> _curve;
};

} // namespace SciFigs

#endif // PLOTLINE_H

==> geopsypack-src-3.4.0.tar.gz: geopsypack-src-3.4.0/SciFigs/src/PlotLine.h <==
/***************************************************************************
**
**  This file is part of SciFigs.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2004-10-07
**  Copyright: 2004-2019
**    Marc Wathelet
**    Marc Wathelet (ULg, Liège, Belgium)
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef PLOTLINE_H
#define PLOTLINE_H

#include "SciFigsDLLExport.h"
#include "AbstractLine.h"

namespace SciFigs {

class SCIFIGS_EXPORT PlotLine : public AbstractLine
{
public:
  virtual AbstractLine * clone() const;
  virtual void operator=(const PlotLine& o);

  virtual int count() const {return _curve.count();}
  virtual void clear() {_curve.clear();}
  virtual void append() {_curve.append(Point());}
  virtual void insert(int index) {_curve.insert(index, Point());}
  virtual void removeLast() {_curve.remove(_curve.count()-1);}
  virtual bool isSorted() const {return _curve.isSorted();}
  virtual void checkSort() {_curve.checkSort();}
  virtual void indexRange(double xMin, double xMax, int& indexMin, int& indexMax) const {
    return _curve.indexRange(xMin, xMax, indexMin, indexMax);
  }
  virtual Point point(int index, const CurvePointOptions *) const {return _curve.constAt(index);}
  virtual void setX(int index, double v) {_curve.setX(index, v);}
  virtual void setY(int index, double v, const CurvePointOptions *) {_curve.setY(index, v);}
  virtual void setZ(int index, double v, const CurvePointOptions *) {_curve.constXAt(index).setZ(v);}

  const Curve<Point>& curve() const {return _curve;}
  Curve<Point>& curve() {return _curve;}
protected:
  Curve<Point> _curve;
};

} // namespace SciFigs

#endif // PLOTLINE_H
